//
//  AviationWeatherStation.h
//
//  Created by C.K. Haun on 10/28/15.
//  Copyright © 2015 Ravenware Industries LLC, All rights reserved.
// License
// You have the explicit right to copy, redistribute, and use any of this content provided that you;
// Acknowledge and agree that any copyright, trademark, service mark, or other is retained by C.K. Haun and Ravenware Industries LLC
// Include a reference to Ravenware.com as the origin of the content
// Acknowledge that there is no representation that any advice or techniques presented on this site are optimum or even correct
// If you use some content in your own content you include the acknowledgment "Some portions of this product created by C.K. Haun and Ravenware Industries LLC"
// You never expect or demand bug fixes or updates
// And most importantly, you agree that if you don't like something here, you don't complain, you just create a better one yourself.
#import <Foundation/Foundation.h>


#if 0
!   CD = 2 letter state (province) abbreviation
!   STATION = 16 character station long name
!   ICAO = 4-character international id
!   IATA = 3-character (FAA) id
!   SYNOP = 5-digit international synoptic number
!   LAT = Latitude (degrees minutes)
!   LON = Longitude (degree minutes)
!   ELEV = Station elevation (meters)
!   M = METAR reporting station.   Also Z=obsolete? site
!   N = NEXRAD (WSR-88D) Radar site
!   V = Aviation-specific flag (V=AIRMET/SIGMET end point, A=ARTCC T=TAF U=T+V)
!   U = Upper air (rawinsonde=X) or Wind Profiler (W) site
!   A = Auto (A=ASOS, W=AWOS, M=Meso, H=Human, G=Augmented) (H/G not yet impl.)
!   C = Office type F=WFO/R=RFC/C=NCEP Center
!   Digit that follows is a priority for plotting (0=highest)
!   Country code (2-char) is last column
#endif

@interface AviationWeatherStation : NSObject <NSCoding,NSCopying>
{   NSString *stateName; // optional unless there is no state abreviation
    NSString *stateAbbreviation; // might not exist
    NSString *stationName;
    NSString *ICAO;
    NSString *IATA;
    NSInteger SYNOPIndex;
    double latitude;
    double longitude;
    NSInteger  ELEV;
    char METAR;
    char NEXRAD;
    char aviationFlag;
    char upperAirOrWind;
    char observationType;
    char officeType;
    char plottingPriority;
    NSString *countryCode;
    NSMutableDictionary *refCon;      // might not exist. Key-value pairs to provide additional data to
                               // a station wihtout having to subclass.
                               // if you generate  a AWSPCK key value that you want to share and add things to this dictionary
                               // please email me the key & value & meaning and I'll include it in this header
                               // and on the docs page.
                               // Also, PLEASE maintain any keys that you might find in a file.
                               // And it's called a refCon becasue I'm old

}

@property (nonatomic, strong) NSString *stateName;
@property (nonatomic, strong) NSString *stateAbbreviation;
@property (nonatomic, strong) NSString *stationName;
@property (nonatomic, strong) NSString *ICAO;
@property (nonatomic, strong) NSString *IATA;
@property (nonatomic, assign) NSInteger SYNOPIndex;
@property (nonatomic, assign) double latitude;
@property (nonatomic, assign) double longitude;
@property (nonatomic, assign) NSInteger ELEV;
@property (nonatomic, assign) char METAR;
@property (nonatomic, assign) char NEXRAD;
@property (nonatomic, assign) char aviationFlag;
@property (nonatomic, assign) char upperAirOrWind;
@property (nonatomic, assign) char observationType;
@property (nonatomic, assign) char officeType;
@property (nonatomic, assign) char plottingPriority;
@property (nonatomic, strong) NSString *countryCode;
@property (nonatomic, strong)     NSMutableDictionary *refCon;

-(id)copyWithZone:(NSZone *)zone;

// my dictionary entry for making a station a favorite
// key CKFavorite as an example... Optional, you can certainly pull this code out if you want
-(BOOL) isFavorite;
-(void) setFavorite:(BOOL) yesOrNo;
-(void)toggleFavoriteStatus;


@end
